==> lebiniou_3.30.orig.tar.gz: lebiniou-3.30/plugins/stable/main/xoscillo_s/xoscillo_s.c <==
/*
 *  Copyright 1994-2019 Olivier Girondel
 *
 *  This file is part of lebiniou.
 *
 *  lebiniou is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  lebiniou is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
 */

#include "oscillo.h"


u_long id = 1089152274;
u_long options = BE_SFX2D|BEQ_HOR;
char dname[] = "X oscillo stereo";
u_long mode = OVERLAY;
char desc[] = "Horizontal stereo oscilloscope";


static Porteuse_t *PL = NULL, *PR = NULL;
static int connect = 1;


static void
init()
{
  uint32_t i;
  Transform_t t;

  memset(&t, 0, sizeof(t));

  PL->origin.x = PR->origin.x = 0;

  PL->origin.y = HHEIGHT/2;
  PR->origin.y = MAXY-HHEIGHT/2;

  t.v_j_factor = HMAXY * 0.85;
  t.v_i.x = 1.0 / (float)(PL->size - 1) * (float)MAXX;

  for (i = 0; i < PL->size; i++)
    PL->trans[i] = PR->trans[i] = t;

  Porteuse_init_alpha(PL);
  Porteuse_init_alpha(PR);
}


void
create(Context_t *ctx)
{
  if (ctx->input != NULL) {
    PL = Porteuse_new(ctx->input->size, A_LEFT);
    PR = Porteuse_new(ctx->input->size, A_RIGHT);
    init();
  } else
    options |= BEQ_DISABLED;
}


void
on_switch_on(Context_t *ctx)
{
  /* connect = b_rand_boolean(); */
}


void
destroy(Context_t *ctx)
{
  if (ctx->input != NULL) {
    Porteuse_delete(PL);
    Porteuse_delete(PR);
  }
}


void
run(Context_t *ctx)
{
  if (ctx->input != NULL) {
    Buffer8_clear(passive_buffer(ctx));
    Porteuse_draw(PL, ctx, connect);
    Porteuse_draw(PR, ctx, connect);
  }
}

==> lebiniou_3.32.orig.tar.gz: lebiniou-3.32/plugins/stable/main/xoscillo_s/xoscillo_s.c <==
/*
 *  Copyright 1994-2019 Olivier Girondel
 *
 *  This file is part of lebiniou.
 *
 *  lebiniou is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  lebiniou is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
 */

#include "oscillo.h"


u_long id = 1089152274;
u_long options = BE_SFX2D|BEQ_HOR;
char dname[] = "X oscillo stereo";
u_long mode = OVERLAY;
char desc[] = "Horizontal stereo oscilloscope";


static Porteuse_t *PL = NULL, *PR = NULL;
static int connect = 1;


static void
init()
{
  uint32_t i;
  Transform_t t;

  memset(&t, 0, sizeof(t));

  PL->origin.x = PR->origin.x = 0;

  PL->origin.y = HHEIGHT/2;
  PR->origin.y = MAXY-HHEIGHT/2;

  t.v_j_factor = HMAXY * 0.85;
  t.v_i.x = 1.0 / (float)(PL->size - 1) * (float)MAXX;

  for (i = 0; i < PL->size; i++) {
    PL->trans[i] = PR->trans[i] = t;
  }

  Porteuse_init_alpha(PL);
  Porteuse_init_alpha(PR);
}


int8_t
create(Context_t *ctx)
{
  PL = Porteuse_new(ctx->input->size, A_LEFT);
  PR = Porteuse_new(ctx->input->size, A_RIGHT);
  init();

  return 1;
}


void
on_switch_on(Context_t *ctx)
{
  /* connect = b_rand_boolean(); */
}


void
destroy(Context_t *ctx)
{
  if (ctx->input != NULL) {
    Porteuse_delete(PL);
    Porteuse_delete(PR);
  }
}


void
run(Context_t *ctx)
{
  Buffer8_clear(passive_buffer(ctx));
  Porteuse_draw(PL, ctx, connect);
  Porteuse_draw(PR, ctx, connect);
}
